@@ -35,7 +35,7 @@ class ChainCRF(GraphCRF):
 
             - 'qpbo' for QPBO + alpha expansion.
             - 'dai' for LibDAI bindings (which has another parameter).
-            - 'lp' for Linear Programming relaxation using GLPK.
+            - 'lp' for Linear Programming relaxation using cvxopt.
             - 'ad3' for AD3 dual decomposition.
 
         If None, ad3 is used if installed, otherwise lp.
@@ -51,6 +51,8 @@ class ChainCRF(GraphCRF):
     """
     def __init__(self, n_states=None, n_features=None, inference_method=None,
                  class_weight=None, directed=True):
+        if inference_method is None:
+            inference_method = "max-product"
         GraphCRF.__init__(self, n_states=n_states, n_features=n_features,
                           inference_method=inference_method,
                           class_weight=class_weight, directed=directed)
